pub struct MemoryBackend { /* private fields */ }Expand description
A naive backend that stores collections and items in memory.
This backend is meant to be used for testing and toy servers, not for production.
Implementations
Sourceimpl MemoryBackend
impl MemoryBackend
Sourcepub fn new() -> MemoryBackend
pub fn new() -> MemoryBackend
Creates a new memory backend.
Examples
use stac_server::MemoryBackend;
let backend = MemoryBackend::new();Trait Implementations
Sourceimpl Backend for MemoryBackend
impl Backend for MemoryBackend
Sourceimpl Clone for MemoryBackend
impl Clone for MemoryBackend
Sourcefn clone(&self) -> MemoryBackend
fn clone(&self) -> MemoryBackend
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CollectionsClient for MemoryBackend
impl CollectionsClient for MemoryBackend
Sourceasync fn collections(&self) -> Result<Vec<Collection>>
async fn collections(&self) -> Result<Vec<Collection>>
Returns all collections.
Sourceasync fn collection(&self, id: &str) -> Result<Option<Collection>>
async fn collection(&self, id: &str) -> Result<Option<Collection>>
Returns a single collection by ID. Read more
Sourceimpl Debug for MemoryBackend
impl Debug for MemoryBackend
Sourceimpl Default for MemoryBackend
impl Default for MemoryBackend
Sourceimpl ItemsClient for MemoryBackend
impl ItemsClient for MemoryBackend
Sourceimpl StreamItemsClient for MemoryBackend
impl StreamItemsClient for MemoryBackend
Sourceasync fn search_stream(
&self,
search: Search,
) -> Result<impl Stream<Item = Result<Item, Error>> + Send>
async fn search_stream( &self, search: Search, ) -> Result<impl Stream<Item = Result<Item, Error>> + Send>
Searches for STAC items, returning a stream of items. Read more
Sourcefn collect_items(
&self,
search: Search,
) -> impl Future<Output = Result<Vec<Map<String, Value>>, Self::Error>> + Send
fn collect_items( &self, search: Search, ) -> impl Future<Output = Result<Vec<Map<String, Value>>, Self::Error>> + Send
Collects all items from all pages into a
Vec. Read moreSourceimpl TransactionClient for MemoryBackend
impl TransactionClient for MemoryBackend
Sourceasync fn add_collection(&mut self, collection: Collection) -> Result<()>
async fn add_collection(&mut self, collection: Collection) -> Result<()>
Adds a collection.